/*
 * Copyright 2012 Adaptrex, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.adaptrex.core.ext.data;

import java.util.HashMap;
import java.util.Map;

import com.adaptrex.core.utilities.StringUtilities;
import com.fasterxml.jackson.annotation.JsonInclude;

public class RestProxy {

	private String url;
	private Map<String,String> reader = new HashMap<String,String>();
	private Map<String,Object> writer = new HashMap<String,Object>();
	private Map<String,Object> extraParams = new HashMap<String,Object>(); 
	
	public RestProxy(String url, DataConfig config) {
		this.url = url;
		
		reader.put("type","json");
		reader.put("root","data");
		reader.put("rootProperty","data");	// Sencha touch uses rootProperty instead of root
		writer.put("writeAllFields", false);
		
		
		if (config.getWhere() != null && !config.getWhere().isEmpty()) {
			String where = config.getWhere();
			extraParams.put("where", where);
		}		
		if (!config.getIncludes().isEmpty()) {
			String include = StringUtilities.join(config.getIncludes(), ",");
			extraParams.put("include", include);
		}
		if (!config.getExcludes().isEmpty()) {
			extraParams.put("exclude", StringUtilities.join(config.getExcludes(), ","));
		}
		if (!config.getAssociationEntityNames().isEmpty()) {
			extraParams.put("associations", StringUtilities.join(config.getAssociationEntityNames(), ","));
		}
		if (!config.getModelName().isEmpty()) {
			extraParams.put("modelname", config.getModelName());
		}			
	}
	
	
	@JsonInclude
	public String getUrl() {
		return this.url;
	}
	
	@JsonInclude
	public String getType() {
		return "rest";
	}
	
	@JsonInclude
	public Map<String,String> getReader() {
		return this.reader;
	}
	
	@JsonInclude
	public Map<String,Object> getWriter() {
		return this.writer;
	}
	
	@JsonInclude
	public Map<String,Object> getExtraParams() {
		return this.extraParams;
	}
}
 